@@ -13,7 +13,11 @@
 #undef GUPPI_MINOR_VERSION
 #undef GUPPI_MICRO_VERSION
 
+#undef USING_OLD_FONT_API
 #undef HAVE_GUILE
+#undef USING_GUILE_1_3_0
+#undef USING_GUILE_1_3_X
+#undef USING_GUILE_1_4_X
 #undef HAVE_HISTORY
 #undef HAVE_READLINE
 #undef WORKING_GUILE_READLINE
@@ -22,5 +26,6 @@
 #undef HAVE_GUILE_GTK
 #undef HAVE_GUILE_GNOME
 #undef USING_BONOBO
+#undef HAVE_PYTHON
 
 
