@@ -1,4 +1,4 @@
-/* $Id: guppi-scatter-state.c,v 1.20 2000/12/17 05:24:54 trow Exp $ */
+/* $Id: guppi-scatter-state.c,v 1.21 2000/12/22 05:35:09 trow Exp $ */
 
 /*
  * guppi-scatter-state.c
@@ -274,6 +274,7 @@ config_cb (gpointer user_data)
       s = guppi_strdup_printf (_("Style #%d"), i + 1);
       gtk_notebook_append_page (notebook, sew, gtk_label_new (s));
       guppi_free (s);
+      gtk_widget_show_all (sew);
     }
 
     gtk_container_add (GTK_CONTAINER (empty_box), GTK_WIDGET (notebook));
@@ -294,6 +295,8 @@ config_cb (gpointer user_data)
   gtk_signal_connect (GTK_OBJECT (w), "destroy",
 		      GTK_SIGNAL_FUNC (destroy_handler), xml);
 
+  gtk_widget_show_all (w);
+
   return w;
 
 
@@ -795,4 +798,4 @@ guppi_scatter_state_brush_circle (GuppiScatterState * ss,
 
 
 
-/* $Id: guppi-scatter-state.c,v 1.20 2000/12/17 05:24:54 trow Exp $ */
+/* $Id: guppi-scatter-state.c,v 1.21 2000/12/22 05:35:09 trow Exp $ */
