@@ -1,4 +1,4 @@
-/* $Id: guppi-slinreg-statviewer.c,v 1.6 2000/12/12 23:11:56 trow Exp $ */
+/* $Id: guppi-slinreg-statviewer.c,v 1.7 2000/12/22 05:35:10 trow Exp $ */
 
 /*
  * guppi-slinreg-statviewer.c
@@ -27,6 +27,7 @@
 
 #include <config.h>
 #include <glade/glade.h>
+#include <gnan.h>
 #include <guppi-convenient.h>
 #include <guppi-paths.h>
 #include "guppi-slinreg-statviewer.h"
@@ -49,7 +50,7 @@ sv_set (GtkWidget * sv, gboolean valid, const gchar * entry,
   g_return_if_fail (w != NULL);
   g_return_if_fail (GTK_IS_LABEL (w));
 
-  if (!valid)
+  if (g_isnan (x) || !valid)
     gtk_label_set_text (GTK_LABEL (w), _("n/a"));
   else {
     g_snprintf (buffer, 32, format ? format : "%g", x);
@@ -147,4 +148,4 @@ guppi_slinreg_statviewer_new (GuppiSimpleLinreg * slr)
   return w;
 }
 
-/* $Id: guppi-slinreg-statviewer.c,v 1.6 2000/12/12 23:11:56 trow Exp $ */
+/* $Id: guppi-slinreg-statviewer.c,v 1.7 2000/12/22 05:35:10 trow Exp $ */
