@@ -1,4 +1,4 @@
-/* $Id: guppi.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: guppi.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
 
 /*
  * guppi.h
@@ -29,12 +29,16 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <guppi-defs.h>
 
-void guppi_add_menubar_item(const gchar* path, const gchar* name);
-void guppi_add_menu(const gchar* path, GnomeUIInfo* menuinfo);
-void guppi_quit(void);
+BEGIN_GUPPI_DECLS
 
+void guppi_add_menubar_item (const gchar * path, const gchar * name);
+void guppi_add_menu (const gchar * path, GnomeUIInfo * menuinfo);
+void guppi_quit (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_H */
 
-/* $Id: guppi.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: guppi.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
