@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-array.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-array.h,v 1.8 2000/10/27 18:22:58 trow Exp $ */
 
 /*
  * guppi-array.h
@@ -28,11 +28,14 @@
 #ifndef _INC_GUPPI_ARRAY_H
 #define _INC_GUPPI_ARRAY_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "guppi-data.h"
 
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
+
 typedef struct _GuppiArray GuppiArray;
 typedef struct _GuppiArrayClass GuppiArrayClass;
 
@@ -52,34 +55,30 @@ struct _GuppiArrayClass {
 #define GUPPI_IS_ARRAY0(obj) (((obj) == NULL) || (GUPPI_IS_ARRAY(obj)))
 #define GUPPI_IS_ARRAY_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_ARRAY))
 
-GtkType guppi_array_get_type(void);
+GtkType guppi_array_get_type (void);
 
-void guppi_array_construct(GuppiArray*, gint,
-				const gint*, const gint*);
+void guppi_array_construct (GuppiArray *, gint, const gint *, const gint *);
 
-GuppiData* guppi_array_new(gint, const gint*, const gint*);
-GuppiData* guppi_array_with_impl_new(GtkType, gint,
-					  const gint*, const gint*);
 
-gint guppi_array_dimensions(const GuppiArray*);
-gint guppi_array_min_index(const GuppiArray*, gint);
-gint guppi_array_max_index(const GuppiArray*, gint);
-void guppi_array_index_bounds(const GuppiArray*, gint,
-				   gint* min, gint* max);
-gboolean guppi_array_valid_index(const GuppiArray*, gint, gint);
-gboolean guppi_array_validv(const GuppiArray*, const gint*);
+gint guppi_array_dimensions (const GuppiArray *);
+gint guppi_array_min_index (const GuppiArray *, gint);
+gint guppi_array_max_index (const GuppiArray *, gint);
+void guppi_array_index_bounds (const GuppiArray *, gint,
+			       gint * min, gint * max);
+gboolean guppi_array_valid_index (const GuppiArray *, gint, gint);
+gboolean guppi_array_validv (const GuppiArray *, const gint *);
 
-double guppi_array_get(const GuppiArray*, ...);
-double guppi_array_getv(const GuppiArray*, const gint*);
+double guppi_array_get (const GuppiArray *, ...);
+double guppi_array_getv (const GuppiArray *, const gint *);
 
-void guppi_array_set(GuppiArray*, double, ...);
-void guppi_array_setv(GuppiArray*, double, const gint*);
+void guppi_array_set (GuppiArray *, double, ...);
+void guppi_array_setv (GuppiArray *, double, const gint *);
 
-GuppiArray* guppi_array_slice(const GuppiArray*, gint dims, ...);
-GuppiArray* guppi_array_slicev(const GuppiArray*,
-			       gint dims, const gint*);
+GuppiArray *guppi_array_slice (const GuppiArray *, gint dims, ...);
+GuppiArray *guppi_array_slicev (const GuppiArray *, gint dims, const gint *);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_ARRAY_H */
 
-/* $Id: guppi-array.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
-
+/* $Id: guppi-array.h,v 1.8 2000/10/27 18:22:58 trow Exp $ */
