@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data-impl.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-data-impl.h,v 1.14 2000/12/12 03:47:46 trow Exp $ */
 
 /*
  * guppi-data-impl.h
@@ -28,29 +28,46 @@
 #ifndef _INC_GUPPI_DATA_IMPL_H
 #define _INC_GUPPI_DATA_IMPL_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <guppi-output-xml.h>
+#include <guppi-defs.h>
 
+BEGIN_GUPPI_DECLS 
+
+struct _GuppiData; /* forward decl */
 typedef struct _GuppiDataImpl GuppiDataImpl;
-typedef struct _GuppiDataImplClass GuppiDataImplClass;
-
-typedef gpointer (*GuppiDataImplHook)(GuppiDataImpl*, gpointer);
 
 struct _GuppiDataImpl {
   GtkObject parent;
 };
 
-struct _GuppiDataImplClass {
+typedef struct {
   GtkObjectClass parent_class;
-  
-  const gchar* impl_name;
-  GHashTable* hooks;
+
+  gboolean read_only;
+
+  const gchar *impl_name;
+
+  /* signals */
+  void (*changed) (GuppiDataImpl *);
+  void (*changed_subdata) (GuppiDataImpl *);
 
   /* virtual functions */
-  GuppiDataImpl* (*copy)(GuppiDataImpl*);
-  gint (*get_size_in_bytes)(GuppiDataImpl*);
-  void (*get_size_info)(GuppiDataImpl*, gchar*, gsize);
-};
+  GuppiDataImpl *(*copy) (GuppiDataImpl *);
+  gint (*get_size_in_bytes) (GuppiDataImpl *);
+  void (*get_size_info) (GuppiDataImpl *, gchar *, gsize);
+
+  void (*write_xml) (GuppiDataImpl *, GuppiOutputXML *);
+  
+  void (*build_menu) (GuppiDataImpl *, GtkMenu *, gpointer data_tree);
+  GtkWidget *(*info_display) (GuppiDataImpl *);
+
+  void (*foreach_subdata) (GuppiDataImpl *, 
+			   void (*fn) (struct _GuppiData *, gpointer),
+			   gpointer user_data);
+			   
+
+} GuppiDataImplClass;
 
 #define GUPPI_TYPE_DATA_IMPL (guppi_data_impl_get_type())
 #define GUPPI_DATA_IMPL(obj) (GTK_CHECK_CAST((obj),GUPPI_TYPE_DATA_IMPL,GuppiDataImpl))
@@ -60,15 +77,16 @@ struct _GuppiDataImplClass {
 #define GUPPI_IS_DATA_IMPL0(obj) (((obj) == NULL) || (GUPPI_IS_DATA_IMPL(obj)))
 #define GUPPI_IS_DATA_IMPL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_DATA_IMPL))
 
-GtkType guppi_data_impl_get_type(void);
+GtkType guppi_data_impl_get_type (void);
 
-const gchar* guppi_data_impl_get_impl_name(const GuppiDataImpl*);
+const gchar *guppi_data_impl_get_impl_name (GuppiDataImpl *);
 
-gboolean guppi_data_impl_has_hook(const GuppiDataImpl*, const gchar*);
-gpointer guppi_data_impl_call_hook(GuppiDataImpl*, const gchar*, gpointer);
-void guppi_data_impl_class_add_hook(GuppiDataImplClass*, const gchar*,
-				    GuppiDataImplHook);
+void guppi_data_impl_changed (GuppiDataImpl *);
+void guppi_data_impl_changed_subdata (GuppiDataImpl *);
+void guppi_data_impl_touch (GuppiDataImpl *);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_DATA_IMPL_H */
 
-/* $Id: guppi-data-impl.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-data-impl.h,v 1.14 2000/12/12 03:47:46 trow Exp $ */
