@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data-importer.h,v 1.4 2000/04/13 01:01:45 trow Exp $ */
+/* $Id: guppi-data-importer.h,v 1.11 2000/12/12 03:47:46 trow Exp $ */
 
 /*
  * guppi-data-importer.h
@@ -28,28 +28,37 @@
 #ifndef _INC_GUPPI_DATA_IMPORTER_H
 #define _INC_GUPPI_DATA_IMPORTER_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <guppi-file.h>
 #include <guppi-stream.h>
 #include "guppi-data.h"
 
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
+
 typedef struct _GuppiDataImporter GuppiDataImporter;
 typedef struct _GuppiDataImporterClass GuppiDataImporterClass;
 
+typedef void (*import_iter_fn) (GuppiData *, gpointer);
+
 struct _GuppiDataImporter {
   GtkObject parent;
 
-  GuppiFile* file;
-  GuppiStream* str;
+  GuppiFile *file;
+  GuppiStream *str;
 };
 
 struct _GuppiDataImporterClass {
   GtkObjectClass parent_class;
 
-  const gchar* name;
-  void (*set_source_hook)(GuppiDataImporter*);
-  GuppiData** (*import)(GuppiDataImporter*);
+  const gchar *name;
+  void (*set_source_hook) (GuppiDataImporter *);
+  void (*import) (GuppiDataImporter *,
+		  void (*iter_fn) (GuppiData *, gpointer),
+		  gpointer);
+
+  GtkWidget *(*state_edit_widget) (GuppiDataImporter *);
 };
 
 #define GUPPI_TYPE_DATA_IMPORTER (guppi_data_importer_get_type())
@@ -60,20 +69,32 @@ struct _GuppiDataImporterClass {
 #define GUPPI_IS_DATA_IMPORTER0(obj) (((obj) == NULL) || (GUPPI_IS_DATA_IMPORTER(obj)))
 #define GUPPI_IS_DATA_IMPORTER_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_DATA_IMPORTER))
 
-GtkType guppi_data_importer_get_type(void);
+GtkType guppi_data_importer_get_type (void);
 
-/* virtual constructor */
-GuppiDataImporter* guppi_data_importer_new(const gchar* name);
+/* virtual constructors */
+GuppiDataImporter *guppi_data_importer_new (const gchar *name, 
+					    const gchar *first_arg_name, ...);
+GuppiDataImporter *guppi_data_importer_newv (const gchar *name,
+					     guint nargs, GtkArg *args);
 
-const gchar* guppi_data_importer_get_name(GuppiDataImporter*);
+const gchar *guppi_data_importer_get_name (GuppiDataImporter *);
 
-void guppi_data_importer_set_source(GuppiDataImporter*, GuppiFile*);
-GuppiFile* guppi_data_importer_file(GuppiDataImporter*);
-GuppiStream* guppi_data_importer_stream(GuppiDataImporter*);
-const gchar* guppi_data_importer_filename(GuppiDataImporter*);
+void guppi_data_importer_set_source (GuppiDataImporter *, GuppiFile *);
+GuppiFile *guppi_data_importer_file (GuppiDataImporter *);
+GuppiStream *guppi_data_importer_stream (GuppiDataImporter *);
+const gchar *guppi_data_importer_filename (GuppiDataImporter *);
 
-GuppiData** guppi_data_importer_import(GuppiDataImporter*);
+gint guppi_data_importer_import (GuppiDataImporter *,
+				 import_iter_fn fn, 
+				 gpointer user_data);
+void guppi_data_importer_import_interactive (GuppiDataImporter *,
+					     import_iter_fn fn,
+					     gpointer fn_user_data,
+					     void (*post_hook) (gint, gpointer),
+					     gpointer post_user_data);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_DATA_IMPORTER_H */
 
-/* $Id: guppi-data-importer.h,v 1.4 2000/04/13 01:01:45 trow Exp $ */
+/* $Id: guppi-data-importer.h,v 1.11 2000/12/12 03:47:46 trow Exp $ */
