@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-impl.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-seq-impl.h,v 1.12 2000/10/28 19:06:47 trow Exp $ */
 
 /*
  * guppi-seq-impl.h
@@ -28,33 +28,48 @@
 #ifndef _INC_GUPPI_SEQ_IMPL_H
 #define _INC_GUPPI_SEQ_IMPL_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "guppi-data.h"
 #include "guppi-data-impl.h"
 #include "guppi-seq.h"
 
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
+
 typedef struct _GuppiSeqImpl GuppiSeqImpl;
-typedef struct _GuppiSeqImplClass GuppiSeqImplClass;
 
 struct _GuppiSeqImpl {
   GuppiDataImpl parent;
+
+  gpointer opaque_missing_values;
 };
 
-struct _GuppiSeqImplClass {
+typedef struct {
   GuppiDataImplClass parent_class;
-  
-  /* Virtual functions */
-  void (*size_hint)(GuppiSeqImpl*, gsize);
-  void (*get_bounds)(const GuppiSeqImpl*, gint* min, gint* max);
-  void (*shift_indices)(GuppiSeqImpl*, gint delta);
-  gboolean (*validate)(const GuppiSeqImpl*, const gchar*, gchar*, gsize);
-  void (*get)(const GuppiSeqImpl*, gint i, gchar*, gsize);
-  void (*set)(GuppiSeqImpl*, gint, const gchar*);
-  void (*insert)(GuppiSeqImpl*, gint, const gchar*);
-  void (*delete_many)(GuppiSeqImpl*, gint, gsize);
-};
+
+  void (*size_hint) (GuppiSeqImpl *, gsize);
+  void (*get_bounds) (const GuppiSeqImpl *, gint *min, gint *max);
+  void (*shift_indices) (GuppiSeqImpl *, gint delta);
+  gboolean (*validate) (const GuppiSeqImpl *, const gchar *, gchar *, gsize);
+
+    gboolean (*has_missing) (GuppiSeqImpl *);
+    gsize (*missing_count) (GuppiSeqImpl *);
+
+    gboolean (*missing) (GuppiSeqImpl *, gint i);
+  void (*get) (const GuppiSeqImpl *, gint i, gchar *, gsize);
+
+  void (*set) (GuppiSeqImpl *, gint, const gchar *);
+  void (*set_missing) (GuppiSeqImpl *, gint);
+
+  void (*insert) (GuppiSeqImpl *, gint, const gchar *);
+  void (*insert_missing) (GuppiSeqImpl *, gint);
+
+  void (*delete_many) (GuppiSeqImpl *, gint, gsize);
+  void (*grow_to_include) (GuppiSeqImpl *, gint, gint);
+
+} GuppiSeqImplClass;
 
 #define GUPPI_TYPE_SEQ_IMPL (guppi_seq_impl_get_type())
 #define GUPPI_SEQ_IMPL(obj) (GTK_CHECK_CAST((obj),GUPPI_TYPE_SEQ_IMPL,GuppiSeqImpl))
@@ -64,12 +79,32 @@ struct _GuppiSeqImplClass {
 #define GUPPI_IS_SEQ_IMPL0(obj) (((obj) == NULL) || (GUPPI_IS_SEQ_IMPL(obj)))
 #define GUPPI_IS_SEQ_IMPL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_SEQ_IMPL))
 
-GtkType guppi_seq_impl_get_type(void);
+GtkType guppi_seq_impl_get_type (void);
 
-GtkObject* guppi_seq_impl_new(void);
+GtkObject *guppi_seq_impl_new (void);
+
+/*
+ * API for low-level implementation of the missing values mask, that
+ * can be used by derived classes.
+ */
+
+gboolean guppi_seq_impl_has_missing (GuppiSeqImpl *);
+gsize guppi_seq_impl_missing_count (GuppiSeqImpl *);
+gboolean guppi_seq_impl_missing (GuppiSeqImpl *, gint i);
+void guppi_seq_impl_set_missing (GuppiSeqImpl *, gint i, gboolean);
+void guppi_seq_impl_set_many_missing (GuppiSeqImpl * impl, gint i, gint N,
+				      gboolean x);
+void guppi_seq_impl_insert_missing (GuppiSeqImpl *, gint i, gboolean x,
+				    gsize N);
+void guppi_seq_impl_delete_missing (GuppiSeqImpl *, gint i, gsize N);
+void guppi_seq_impl_clear_missing (GuppiSeqImpl *);
+
+void guppi_seq_impl_debug_missing (GuppiSeqImpl *);
 
 
 
+END_GUPPI_DECLS
+
 #endif /* _INC_GUPPI_SEQ_IMPL_H */
 
-/* $Id: guppi-seq-impl.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-seq-impl.h,v 1.12 2000/10/28 19:06:47 trow Exp $ */
