@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-struct.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-struct.h,v 1.8 2000/11/18 02:53:21 trow Exp $ */
 
 /*
  * guppi-struct.h
@@ -28,11 +28,14 @@
 #ifndef _INC_GUPPI_STRUCT_H
 #define _INC_GUPPI_STRUCT_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "guppi-data.h"
 
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
+
 typedef struct _GuppiStruct GuppiStruct;
 typedef struct _GuppiStructClass GuppiStructClass;
 
@@ -52,26 +55,29 @@ struct _GuppiStructClass {
 #define GUPPI_IS_STRUCT0(obj) (((obj) == NULL) || (GUPPI_IS_STRUCT(obj)))
 #define GUPPI_IS_STRUCT_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_STRUCT))
 
-GtkType guppi_struct_get_type(void);
+GtkType guppi_struct_get_type (void);
 
-GuppiData* guppi_struct_new(void);
+GuppiData *guppi_struct_new (void);
 
-GtkType guppi_struct_get_field_type(const GuppiStruct*, const gchar*);
-gchar** guppi_struct_get_field_names(const GuppiStruct*);
-
-gsize guppi_struct_size(const GuppiStruct*);
-
-GuppiData* guppi_struct_get(const GuppiStruct*, const gchar*);
-void guppi_struct_set(GuppiStruct*, const gchar*, GuppiData*);
-
-void guppi_struct_add_field(GuppiStruct*, const gchar*, GtkType);
-void guppi_struct_add_free_field(GuppiStruct*, const gchar*);
+GtkType guppi_struct_get_field_type (const GuppiStruct *, const gchar *);
+gchar **guppi_struct_get_field_names (const GuppiStruct *);
 
+gsize guppi_struct_size (const GuppiStruct *);
 
+GuppiData *guppi_struct_get (const GuppiStruct *, const gchar *);
+void guppi_struct_set (GuppiStruct *, const gchar *, GuppiData *);
 
+void guppi_struct_add_field (GuppiStruct *, const gchar *, GtkType);
+void guppi_struct_add_free_field (GuppiStruct *, const gchar *);
+
+void guppi_struct_foreach_subdata (GuppiStruct *,
+				   void (*fn) (const gchar *, GuppiData *,
+					       gpointer),
+				   gpointer user_data);
 
 
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_STRUCT_H */
 
-/* $Id: guppi-struct.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-struct.h,v 1.8 2000/11/18 02:53:21 trow Exp $ */
