@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-item.c,v 1.29 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.31 2000/12/21 22:23:33 trow Exp $ */
 
 /*
  * guppi-element-canvas-item.c
@@ -28,7 +28,6 @@
 #include <config.h>
 #include <math.h>
 #include <guppi-useful.h>
-#include <guppi-dharma.h>
 #include <guppi-unique-id.h>
 #include "guppi-element-view.h"
 #include "guppi-canvas-item.h"
@@ -198,8 +197,6 @@ update (GnomeCanvasItem * item, double aff[6], ArtSVP * clip_path, gint flags)
 
   guppi_canvas_item_request_total_redraw (gec);
 
-  guppi_dharma_turn_wheel ();
-
   GUPPI_EXIT;
 }
 
@@ -1375,5 +1372,5 @@ guppi_canvas_item_class_set_item_class_toolkit (GuppiCanvasItemClass *klass,
 }
 
 
-/* $Id: guppi-canvas-item.c,v 1.29 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.31 2000/12/21 22:23:33 trow Exp $ */
 
