@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-plug-in.h,v 1.3 2000/02/11 07:30:11 trow Exp $ */
+/* $Id: guppi-plot-plug-in.h,v 1.7 2000/10/27 18:23:00 trow Exp $ */
 
 /*
  * guppi-plot-plug-in.h
@@ -28,11 +28,14 @@
 #ifndef _INC_GUPPI_PLOT_PLUG_IN_H
 #define _INC_GUPPI_PLOT_PLUG_IN_H
 
-#include <config.h>
 #include <gnome.h>
 
 #include <guppi-plug-in.h>
-#include "guppi-plot-element.h"
+#include "guppi-element-state.h"
+
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
 
 typedef struct _GuppiPlotPlugIn GuppiPlotPlugIn;
 typedef struct _GuppiPlotPlugInClass GuppiPlotPlugInClass;
@@ -40,7 +43,7 @@ typedef struct _GuppiPlotPlugInClass GuppiPlotPlugInClass;
 struct _GuppiPlotPlugIn {
   GuppiPlugIn parent;
 
-  GuppiPlotElement* (*element_constructor)(void);
+  GuppiElementState *(*element_constructor) (void);
 };
 
 struct _GuppiPlotPlugInClass {
@@ -55,12 +58,14 @@ struct _GuppiPlotPlugInClass {
 #define GUPPI_IS_PLOT_PLUG_IN0(obj) (((obj) == NULL) || (GUPPI_IS_PLOT_PLUG_IN(obj)))
 #define GUPPI_IS_PLOT_PLUG_IN_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_PLOT_PLUG_IN))
 
-GtkType guppi_plot_plug_in_get_type(void);
+GtkType guppi_plot_plug_in_get_type (void);
 
-GuppiPlugIn* guppi_plot_plug_in_new(void);
+GuppiPlugIn *guppi_plot_plug_in_new (void);
 
 
 
+END_GUPPI_DECLS
+
 #endif /* _INC_GUPPI_PLOT_PLUG_IN_H */
 
-/* $Id: guppi-plot-plug-in.h,v 1.3 2000/02/11 07:30:11 trow Exp $ */
+/* $Id: guppi-plot-plug-in.h,v 1.7 2000/10/27 18:23:00 trow Exp $ */
