@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: jitter.h,v 1.2 2000/02/06 03:17:13 trow Exp $ */
+/* $Id: jitter.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
 
 /*
  * jitter.h
@@ -28,13 +28,17 @@
 #ifndef _INC_JITTER_H
 #define _INC_JITTER_H
 
-#include <config.h>
 #include <gnome.h>
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
 
 /* Return "quasi-random" (x,y) values s.t. |(x,y)| <= 1 */
-void jitter(guint seed, double size, gint i, double* xj, double* yj);
+void jitter (guint seed, double size, gint i, double *xj, double *yj);
 
 
+END_GUPPI_DECLS
+
 #endif /* _INC_JITTER_H */
 
-/* $Id: jitter.h,v 1.2 2000/02/06 03:17:13 trow Exp $ */
+/* $Id: jitter.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
