@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-simple-linreg.c,v 1.12 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-simple-linreg.c,v 1.13 2000/12/22 05:35:11 trow Exp $ */
 
 /*
  * guppi-simple-linreg.c
@@ -27,6 +27,7 @@
 
 #include <config.h>
 #include <math.h>
+#include <gnan.h>
 #include <guppi-convenient.h>
 #include <guppi-specfns.h>
 #include <guppi-seq.h>
@@ -227,9 +228,17 @@ guppi_simple_linreg_recalc (GuppiSimpleLinreg * slr)
       slr->tss_y = ssq_y;
       slr->mean_x = mean_x;
       slr->mean_y = mean_y;
-      slr->R = ssq_xy / sqrt (ssq_x * ssq_y);
+      if (ssq_x * ssq_y > 0)
+	slr->R = ssq_xy / sqrt (ssq_x * ssq_y);
+      else
+	slr->R = NAN;
+
       slr->Rsq = slr->R * slr->R;
-      slr->adj_Rsq = slr->Rsq - 1 / (count - 2.0) * (1 - slr->Rsq);
+      
+      if (count > 2)
+	slr->adj_Rsq = slr->Rsq - 1 / (count - 2.0) * (1 - slr->Rsq);
+      else
+	slr->adj_Rsq = NAN;
 
       /* Our second pass --- we calculate info about residuals */
 
@@ -268,26 +277,57 @@ guppi_simple_linreg_recalc (GuppiSimpleLinreg * slr)
 	}
       }
 
-      slr->residual_sdev = sqrt (slr->rss / (slr->count - 2));
+      if (slr->rss >= 0 && slr->count > 2)
+	slr->residual_sdev = sqrt (slr->rss / (slr->count - 2));
+      else
+	slr->residual_sdev = NAN;
 
-      slr->slope_serr = slr->residual_sdev / sqrt (slr->tss_x);
-      slr->intercept_serr = slr->residual_sdev *
-	sqrt (1.0 / slr->count + mean_x * mean_x / slr->tss_x);
+      if (slr->tss_x > 0)
+	slr->slope_serr = slr->residual_sdev / sqrt (slr->tss_x);
+      else
+	slr->slope_serr = NAN;
+      
+      if (slr->count > 0 && slr->tss_x > 0)
+	slr->intercept_serr = slr->residual_sdev *
+	  sqrt (1.0 / slr->count + mean_x * mean_x / slr->tss_x);
+      else
+	slr->intercept_serr = NAN;
 
-      slr->slope_t = slr->slope / slr->slope_serr;
-      slr->intercept_t = slr->intercept / slr->intercept_serr;
+      if (slr->slope_serr > 0)
+	slr->slope_t = slr->slope / slr->slope_serr;
+      else
+	slr->slope_t = NAN;
 
-      slr->slope_p =
-	1 - (t_cdf (slr->count - 2, fabs (slr->slope_t)) -
-	     t_cdf (slr->count - 2, -fabs (slr->slope_t)));
-      slr->intercept_p =
-	1 - (t_cdf (slr->count - 2, fabs (slr->intercept_t)) -
-	     t_cdf (slr->count - 2, -fabs (slr->intercept_t)));
+      if (slr->intercept_serr > 0)
+	slr->intercept_t = slr->intercept / slr->intercept_serr;
+      else
+	slr->intercept_t = NAN;
 
-      slr->F = slr->ess / (slr->rss / (slr->count - 2));
-      slr->p =
-	1 - (t_cdf (slr->count - 2, sqrt (slr->F)) -
-	     t_cdf (slr->count - 2, -sqrt (slr->F)));
+      if (!g_isnan (slr->slope_t)) 
+	slr->slope_p =
+	  1 - (t_cdf (slr->count - 2, fabs (slr->slope_t)) -
+	       t_cdf (slr->count - 2, -fabs (slr->slope_t)));
+      else
+	slr->slope_p = NAN;
+
+      if (!g_isnan (slr->intercept_t)) 
+	slr->intercept_p =
+	  1 - (t_cdf (slr->count - 2, fabs (slr->intercept_t)) -
+	       t_cdf (slr->count - 2, -fabs (slr->intercept_t)));
+      else
+	slr->intercept_t = NAN;
+	  
+      if (slr->rss > 0 && slr->count > 2)
+	slr->F = slr->ess / (slr->rss / (slr->count - 2));
+      else
+	slr->F = NAN;
+
+      if (!g_isnan (slr->F))
+	slr->p =
+	  1 - (t_cdf (slr->count - 2, sqrt (slr->F)) -
+	       t_cdf (slr->count - 2, -sqrt (slr->F)));
+      else
+	slr->p = NAN;
 
       slr->valid = TRUE;
 
@@ -471,4 +511,4 @@ guppi_simple_linreg_F_p (const GuppiSimpleLinreg * slr)
 
 
 
-/* $Id: guppi-simple-linreg.c,v 1.12 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-simple-linreg.c,v 1.13 2000/12/22 05:35:11 trow Exp $ */
