@@ -1,6 +1,6 @@
 /* This is -*- C -*- */
 /* vim: set sw=2: */
-/* $Id: gnan.h,v 1.1 2000/12/12 18:31:06 trow Exp $ */
+/* $Id: gnan.h,v 1.2 2000/12/21 22:23:33 trow Exp $ */
 
 /*
  * gnan.h
@@ -28,6 +28,7 @@
 #ifndef _INC_GNAN_H
 #define _INC_GNAN_H
 
+#include <gtk/gtk.h>
 #include <math.h>
 #include "guppi-defs.h"
 
@@ -37,6 +38,8 @@ BEGIN_GUPPI_DECLS;
 extern const double NAN;
 #endif
 
+gboolean g_isnan (double x);
+
 void gnan_init (void);
 
 END_GUPPI_DECLS;
@@ -44,4 +47,4 @@ END_GUPPI_DECLS;
 
 #endif /* _INC_GNAN_H */
 
-/* $Id: gnan.h,v 1.1 2000/12/12 18:31:06 trow Exp $ */
+/* $Id: gnan.h,v 1.2 2000/12/21 22:23:33 trow Exp $ */
