@@ -1,4 +1,4 @@
-/* $Id: guppi-defaults.c,v 1.1 2000/04/13 19:45:21 trow Exp $ */
+/* $Id: guppi-defaults.c,v 1.5 2000/10/20 01:21:55 trow Exp $ */
 
 /*
  * guppi-defaults.c
@@ -24,33 +24,73 @@
  * USA
  */
 
+#include <config.h>
 #include "guppi-defaults.h"
 
-GnomeFont*
-guppi_default_font(void)
+GnomeFont *
+guppi_default_font_large (void)
 {
-  static GnomeFont* font = NULL;
+  static GnomeFont *font = NULL;
 
   if (font == NULL) {
-    font = gnome_font_new("Helvetica", 12.0);
+    font = gnome_font_new ("Helvetica", 20.0);
     if (font == NULL)
-      g_error("Can't find default font.");
+      g_error ("Can't find default font.");
   }
-
   return font;
 }
 
+
+GnomeFont *
+guppi_default_font_medium (void)
+{
+  static GnomeFont *font = NULL;
+
+  if (font == NULL) {
+    font = gnome_font_new ("Helvetica", 12.0);
+    if (font == NULL)
+      g_error ("Can't find default font.");
+  }
+  return font;
+}
+
+GnomeFont *
+guppi_default_font_small (void)
+{
+  static GnomeFont *font = NULL;
+
+  if (font == NULL) {
+    font = gnome_font_new ("Helvetica", 9.0);
+    if (font == NULL)
+      g_error ("Can't find default font.");
+  }
+  return font;
+}
+
+GnomeFont *
+guppi_default_font (void)
+{
+  return guppi_default_font_medium ();
+}
+
 double
-guppi_default_axis_label_size(void)
+guppi_default_axis_label_size (void)
 {
   return 14.0;
 }
 
 double
-guppi_default_plot_label_size(void)
+guppi_default_plot_label_size (void)
 {
   return 12.0;
 }
 
 
-/* $Id: guppi-defaults.c,v 1.1 2000/04/13 19:45:21 trow Exp $ */
+guppi_metric_t
+guppi_default_units (void)
+{
+  return GUPPI_IN;		/* I'll be Anglocentric for now... */
+}
+
+
+/* $Id: guppi-defaults.c,v 1.5 2000/10/20 01:21:55 trow Exp $ */
