@@ -1,4 +1,4 @@
-/* $Id: guppi-splash.c,v 1.15 2000/12/14 20:23:14 trow Exp $ */
+/* $Id: guppi-splash.c,v 1.16 2000/12/21 22:23:33 trow Exp $ */
 
 /*
  * guppi-splash.c
@@ -106,14 +106,18 @@ guppi_splash_text (void)
     "For Guppi news and information, visit http://www.gnome.org/guppi.",
     NULL
   };
+  const gchar **strv;
 
   gint i;
 
   fputc ('\n', stderr);
   fprintf (stderr, "Guppi (version %s)\n", guppi_version ());
 
-  fputs (guppi_copyright (), stderr);
-  fputc ('\n', stderr);
+  strv = guppi_copyright ();
+  for (i=0; strv[i]; ++i) {
+    fputs (strv[i], stderr);
+    fputc ('\n', stderr);
+  }
 
   for (i = 0; msg[i] != NULL; ++i) {
     fputs (msg[i], stderr);
@@ -224,4 +228,4 @@ guppi_splash_message (const gchar * line1, const gchar * line2)
   }
 }
 
-/* $Id: guppi-splash.c,v 1.15 2000/12/14 20:23:14 trow Exp $ */
+/* $Id: guppi-splash.c,v 1.16 2000/12/21 22:23:33 trow Exp $ */
