@@ -1,4 +1,4 @@
-/* $Id: guppi-timer.c,v 1.3 2000/10/20 01:21:56 trow Exp $ */
+/* $Id: guppi-timer.c,v 1.4 2000/12/21 22:23:33 trow Exp $ */
 
 /*
  * guppi-timer.c
@@ -26,6 +26,7 @@
 #include <config.h>
 #include <time.h>
 #include "guppi-timer.h"
+#include "guppi-dharma.h"
 
 static time_t init_time;
 static time_t active_basis_time;
@@ -55,6 +56,7 @@ emission_monitor (GtkObject * obj, guint sigid, guint n_params,
 		  GtkArg * params, gpointer data)
 {
   guppi_timer_heartbeat ();
+  guppi_dharma_turn_wheel ();
   return TRUE;
 }
 
@@ -115,4 +117,4 @@ guppi_timer_total_active_time (void)
 }
 
 
-/* $Id: guppi-timer.c,v 1.3 2000/10/20 01:21:56 trow Exp $ */
+/* $Id: guppi-timer.c,v 1.4 2000/12/21 22:23:33 trow Exp $ */
