@@ -1,4 +1,4 @@
-/* $Id: guppi-timer.h,v 1.1 2000/02/22 19:39:30 trow Exp $ */
+/* $Id: guppi-timer.h,v 1.6 2000/10/27 18:23:05 trow Exp $ */
 
 /*
  * guppi-timer.h
@@ -26,16 +26,21 @@
 #ifndef _INC_GUPPI_TIMER_H
 #define _INC_GUPPI_TIMER_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
-void guppi_timer_init(void);
-void guppi_timer_terminate(void);
-void guppi_timer_heartbeat(void);
-guint guppi_timer_total_elapsed_time(void);
-guint guppi_timer_total_active_time(void);
+#include <guppi-defs.h>
 
+BEGIN_GUPPI_DECLS 
+
+void guppi_timer_init (void);
+void guppi_timer_terminate (void);
+void guppi_timer_heartbeat (void);
+guint guppi_timer_total_elapsed_time (void);
+guint guppi_timer_total_active_time (void);
+
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_TIMER_H */
 
-/* $Id: guppi-timer.h,v 1.1 2000/02/22 19:39:30 trow Exp $ */
+/* $Id: guppi-timer.h,v 1.6 2000/10/27 18:23:05 trow Exp $ */
